#ifndef __DIGI_DOC_PKCS11_H__
#define __DIGI_DOC_PKCS11_H__
//==================================================
// FILE:	DigiDocPKCS11.h
// PROJECT:     Digi Doc
// DESCRIPTION: Digi Doc functions for signing using PKCS#11 API
// AUTHOR:  Veiko Sinivee, S|E|B IT Partner Estonia
//==================================================
// Copyright (C) AS Sertifitseerimiskeskus
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// GNU Lesser General Public Licence is available at
// http://www.gnu.org/copyleft/lesser.html
//==========< HISTORY >=============================
//      13.01.2004      Veiko Sinivee
//                      Creation
//==================================================


#ifdef  __cplusplus
extern "C" {
#endif

#ifdef WIN32
	#include <windows.h>
	#define LIBHANDLE   HANDLE
	#include "pkcs11/cryptoki.h"
#else
	#include <dlfcn.h>   // Linux .so loading interface
	#define LIBHANDLE   void*
	#include "pkcs11/pkcs11.h"
#endif



#include <DigiDocLib.h>
#include <openssl/ocsp.h>


EXP_OPTION LIBHANDLE initPKCS11Library(const char* libName);
EXP_OPTION void closePKCS11Library(LIBHANDLE pLibrary, CK_SESSION_HANDLE hSession);
EXP_OPTION int calculateSignatureWithEstID(SignedDoc* pSigDoc, SignatureInfo* pSigInfo, 
				int slot, const char* passwd);

CK_RV GetSlotIds(CK_SLOT_ID_PTR pSlotids, CK_ULONG_PTR pLen);
CK_RV GetTokenInfo(CK_TOKEN_INFO_PTR pTokInfo, CK_SLOT_ID id);
int loadAndTestDriver(const char* driver, LIBHANDLE* pLibrary, CK_SLOT_ID* slotids, 
		      int slots, CK_ULONG slot);
CK_RV getDriverInfo(CK_INFO_PTR pInfo);
CK_RV GetSlotInfo(CK_SLOT_INFO_PTR pSlotInfo, CK_SLOT_ID id);

#ifdef WIN32 // probably obsolete ???

EXP_OPTION int signOCSPRequestWithPKCS11onWin(OCSP_REQUEST *req, int slot, const char* passwd);


#endif

#ifdef  __cplusplus
}
#endif

#endif // __DIGI_DOC_PKCS11_H__

